The application can register URI schemes to handle actions like single-sign-on, deep
application linking or to perform cross-application communication.

A malicious application can register a URI already in use by a genuine application
and be able to intercept data intended for it, which can contain sensitive information
like OAuth authorization codes or tokens.
